@@ -301,6 +301,7 @@ cm_Analyze(cm_conn_t *connp,
            struct cm_fid *fidp,
            cm_cell_t *cellp,
            afs_uint32 storeOp,
+           AFSFetchStatus *statusp,
            AFSVolSync *volSyncp,
            cm_serverRef_t * serversp,
            cm_callbackRequest_t *cbrp,
@@ -324,6 +325,7 @@ cm_Analyze(cm_conn_t *connp,
     int location_updated = 0;
     char *format;
     DWORD msgID;
+    int invalid_status = 0;
 
     osi_Log2(afsd_logp, "cm_Analyze connp 0x%p, code 0x%x",
              connp, errorCode);
@@ -359,6 +361,18 @@ cm_Analyze(cm_conn_t *connp,
     else
         timeLeft = 0x0FFFFFFF;
 
+    /*
+     * Similar to the UNIX cache manager, if the AFSFetchStatus info
+     * returned by the file server is invalid, consider the response
+     * as being equivalent to VBUSY so that another file server can
+     * be queried if there is one.  If there is no replica, then the
+     * request will fail.
+     */
+    if (errorCode == 0 && statusp && !cm_IsStatusValid(statusp)) {
+        invalid_status = 1;
+        errorCode = VBUSY;
+    }
+
     /* get a pointer to the cell */
     if (errorCode) {
         if (cellp == NULL && serverp)
@@ -601,8 +615,13 @@ cm_Analyze(cm_conn_t *connp,
 
             switch ( errorCode ) {
             case VBUSY:
-                msgID = MSG_SERVER_REPORTS_VBUSY;
-                format = "Server %s reported busy when accessing volume %d in cell %s.";
+                if (invalid_status) {
+                    msgID = MSG_SERVER_REPLIED_BAD_STATUS;
+                    format = "Server %s replied with bad status info when accessing volume %d in cell %s.  Data discarded by cache manager.";
+                } else {
+                    msgID = MSG_SERVER_REPORTS_VBUSY;
+                    format = "Server %s reported busy when accessing volume %d in cell %s.";
+                }
                 break;
             case VRESTARTING:
                 msgID = MSG_SERVER_REPORTS_VRESTARTING;
@@ -771,6 +790,11 @@ cm_Analyze(cm_conn_t *connp,
                         }
                     }
                     break;
+                case VOFFLINE:
+                    osi_Log2(afsd_logp, "VOFFLINE received for volume %u from server %s",
+                              fidp->volume, osi_LogSaveString(afsd_logp,addr));
+                    tsrp->status = srv_offline;
+                    break;
                 default:
                     osi_Log3(afsd_logp, "volume %u exists on server %s with status %u",
                              fidp->volume, osi_LogSaveString(afsd_logp,addr), tsrp->status);
@@ -1286,6 +1310,8 @@ cm_Analyze(cm_conn_t *connp,
 	    case CM_ERROR_ALLDOWN           : s = "CM_ERROR_ALLDOWN";            break;
 	    case CM_ERROR_TOOFEWBUFS	    : s = "CM_ERROR_TOOFEWBUFS";         break;
 	    case CM_ERROR_TOOMANYBUFS	    : s = "CM_ERROR_TOOMANYBUFS";        break;
+            case UAEIO                      : s = "UAEIO";                       break;
+            case EIO                        : s = "EIO";                         break;
             }
             osi_Log2(afsd_logp, "cm_Analyze: ignoring error code 0x%x (%s)",
                      errorCode, s);
@@ -1585,6 +1611,7 @@ long cm_ConnByServer(cm_server_t *serverp, cm_user_t *userp, afs_uint32 replicat
                 break;
         }
         if (tcp) {
+            InterlockedIncrement(&tcp->refCount);
             lock_ReleaseWrite(&cm_connLock);
             goto haveconn;
         }
@@ -1603,10 +1630,10 @@ long cm_ConnByServer(cm_server_t *serverp, cm_user_t *userp, afs_uint32 replicat
         lock_ReleaseWrite(&cm_connLock);
         lock_ReleaseMutex(&userp->mx);
     } else {
+        InterlockedIncrement(&tcp->refCount);
         lock_ReleaseRead(&cm_connLock);
       haveconn:
         lock_ReleaseMutex(&userp->mx);
-        InterlockedIncrement(&tcp->refCount);
 
         lock_ObtainMutex(&tcp->mx);
         if ((tcp->flags & CM_CONN_FLAG_FORCE_NEW) ||
