@@ -290,25 +290,41 @@ AFSValidateProcessEntry( IN HANDLE ProcessId)
             pProcessCB == NULL)
         {
 
-            AFSProcessCreate( 0,
-                              ProcessId,
-                              0,
-                              0);
-        }
-
-        if( !NT_SUCCESS( ntStatus) ||
-            pProcessCB == NULL)
-        {
-
-            AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
-                          AFS_TRACE_LEVEL_ERROR,
-                          "%s Failed to locate process entry for ProcessID %I64X\n",
-                          __FUNCTION__,
-                          ullProcessID);
-
             AFSReleaseResource( pDeviceExt->Specific.Control.ProcessTree.TreeLock);
 
-            try_return( ntStatus = STATUS_UNSUCCESSFUL);
+            AFSAcquireExcl( pDeviceExt->Specific.Control.ProcessTree.TreeLock,
+                            TRUE);
+
+            ntStatus = AFSLocateHashEntry( pDeviceExt->Specific.Control.ProcessTree.TreeHead,
+                                           ullProcessID,
+                                           (AFSBTreeEntry **)&pProcessCB);
+
+            if( !NT_SUCCESS( ntStatus) ||
+                pProcessCB == NULL)
+            {
+
+                AFSProcessCreate( 0,
+                                  ProcessId,
+                                  0,
+                                  0);
+            }
+
+            if( !NT_SUCCESS( ntStatus) ||
+                pProcessCB == NULL)
+            {
+
+                AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                              AFS_TRACE_LEVEL_ERROR,
+                              "%s Failed to locate process entry for ProcessID %I64X\n",
+                              __FUNCTION__,
+                              ullProcessID);
+
+                AFSReleaseResource( pDeviceExt->Specific.Control.ProcessTree.TreeLock);
+
+                try_return( ntStatus = STATUS_UNSUCCESSFUL);
+            }
+
+            AFSConvertToShared( pDeviceExt->Specific.Control.ProcessTree.TreeLock);
         }
 
         //
@@ -356,6 +372,24 @@ AFSValidateProcessEntry( IN HANDLE ProcessId)
 
         AFSReleaseResource( pDeviceExt->Specific.Control.ProcessTree.TreeLock);
 
+#if defined(_WIN64)
+
+        //
+        // Mark the process as 64-bit if it is.
+        //
+
+        if( !IoIs32bitProcess( NULL))
+        {
+
+            SetFlag( pProcessCB->Flags, AFS_PROCESS_FLAG_IS_64BIT);
+        }
+        else
+        {
+
+            ClearFlag( pProcessCB->Flags, AFS_PROCESS_FLAG_IS_64BIT);
+        }
+#endif
+
         //
         // Locate the SID for the caller
         //
@@ -816,15 +850,6 @@ AFSInitializeProcessCB( IN ULONGLONG ParentProcessId,
 
         pProcessCB->ParentProcessId = (ULONGLONG)ParentProcessId;
 
-#if defined(_WIN64)
-
-        if( !IoIs32bitProcess( NULL))
-        {
-            SetFlag( pProcessCB->Flags, AFS_PROCESS_FLAG_IS_64BIT);
-        }
-
-#endif
-
         if( pDeviceExt->Specific.Control.ProcessTree.TreeHead == NULL)
         {
             pDeviceExt->Specific.Control.ProcessTree.TreeHead = (AFSBTreeEntry *)pProcessCB;
