@@ -73,14 +73,25 @@ typedef struct _AFS_WORKER_QUEUE_HDR
 // These are the context control blocks for the open instance
 //
 
+typedef struct _AFS_NONPAGED_CCB
+{
+
+    ERESOURCE           CcbLock;
+
+} AFSNonPagedCcb;
+
+
 typedef struct _AFS_CCB
 {
 
     USHORT        Size;
+
     USHORT        Type;
 
     ULONG         Flags;
 
+    AFSNonPagedCcb  *NPCcb;
+
     AFSListEntry  ListEntry;
 
     //
@@ -167,6 +178,8 @@ typedef struct _AFS_NONPAGED_OBJECT_INFO_CB
 
     ERESOURCE           DirectoryNodeHdrLock;
 
+    ERESOURCE           ObjectInfoLock;
+
 } AFSNonPagedObjectInfoCB;
 
 typedef struct _AFS_OBJECT_INFORMATION_CB
@@ -258,36 +271,36 @@ typedef struct _AFS_OBJECT_INFORMATION_CB
 
 			struct _AFS_DIRECTORY_CB  *DirectoryNodeListTail;
 
-            LONG                       DirectoryNodeCount;
+                        LONG                       DirectoryNodeCount;
 
 			struct _AFS_DIRECTORY_CB  *ShortNameTree;
 
-            //
-            // PIOCtl directory cb entry
-            //
+                        //
+                        // PIOCtl directory cb entry
+                        //
 
-            struct _AFS_DIRECTORY_CB  *PIOCtlDirectoryCB;
+                        struct _AFS_DIRECTORY_CB  *PIOCtlDirectoryCB;
 
-            //
-            // Open handle and reference count for this object
-            //
+                        //
+                        // Open handle and reference count for this object
+                        //
 
-            LONG                       ChildOpenHandleCount;
+                        LONG                       ChildOpenHandleCount;
 
-            LONG                       ChildOpenReferenceCount;
+                        LONG                       ChildOpenReferenceCount;
 
-            //
-            // Index for the PIOCtl and share open count
-            //
+                        //
+                        // Index for the PIOCtl and share open count
+                        //
 
-            LONG                OpenRequestIndex;
+                        LONG                OpenRequestIndex;
 
 		} Directory;
 
 		struct
 		{
 
-            ULONG       Reserved;
+                        ULONG       Reserved;
 
 		} File;
 
@@ -634,6 +647,15 @@ typedef struct _AFS_WORK_ITEM
 
         } CacheAccess;
 
+        struct
+        {
+
+            AFSObjectInfoCB *ObjectInfo;
+
+            ULONG            InvalidateReason;
+
+        } Invalidate;
+
         struct
         {
             char     Context[ 1];
@@ -664,4 +686,13 @@ typedef struct _AFS_DIRECTORY_SS_HDR
 
 } AFSSnapshotHdr;
 
+typedef struct _AFS_BYTE_RANGE
+{
+
+    LARGE_INTEGER       FileOffset;
+
+    LARGE_INTEGER       Length;
+
+} AFSByteRange;
+
 #endif /* _AFS_STRUCTS_H */
